@@ -358,9 +358,9 @@ void GdbDriver::parseMarker()
     // extract filename and line number
     static TQRegExp MarkerRE(":[0-9]+:[0-9]+:[begmidl]+:0x");
 
-    int len;
-    int lineNoStart = MarkerRE.match(startMarker, 0, &len);
+    int lineNoStart = MarkerRE.search(startMarker, 0);
     if (lineNoStart >= 0) {
+	int len = MarkerRE.matchedLength();
 	int lineNo = atoi(startMarker + lineNoStart+1);
 
 	// get address
