@@ -6,13 +6,13 @@
 
 #include "debugger.h"
 #include "sourcewnd.h"
-#include <ntqtextstream.h>
-#include <ntqpainter.h>
-#include <ntqbrush.h>
-#include <ntqfile.h>
-#include <ntqfileinfo.h>
-#include <ntqkeycode.h>
-#include <ntqpopupmenu.h>
+#include <tqtextstream.h>
+#include <tqpainter.h>
+#include <tqbrush.h>
+#include <tqfile.h>
+#include <tqfileinfo.h>
+#include <tqkeycode.h>
+#include <tqpopupmenu.h>
 #include <tdeapplication.h>
 #include <kiconloader.h>
 #include <tdeglobalsettings.h>
